@@ -1,4 +1,4 @@
-use crate::interface::{EditableSequence, Sequence, SequenceMut};
+use crate::interface::{CloneableSequence, EditableSequence, OwnedSequence, Sequence, SequenceMut};
 
 impl<'a, Item: 'a> Sequence<'a, Item, [Item]> for Vec<Item> {
     type Iterator = std::slice::Iter<'a, Item>;
@@ -19,4 +19,8 @@ impl<'a, Item: 'a> SequenceMut<'a, Item, [Item]> for Vec<Item> {
     }
 }
 
+impl<'a, Item: 'a> OwnedSequence<'a, Item, [Item]> for Vec<Item> {}
+
+impl<'a, Item: 'a + Clone> CloneableSequence<'a, Item, [Item]> for Vec<Item> {}
+
 impl<'a, Item: 'a> EditableSequence<'a, Item, [Item]> for Vec<Item> {}
